@@ -20,11 +20,11 @@ Net::eBay - Perl Interface to XML based eBay API.
 
 =head1 VERSION
 
-Version 0.20
+Version 0.21
 
 =cut
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 =head1 SYNOPSIS
 
@@ -482,6 +482,8 @@ sub hash2xml {
             && defined $r->{_value}
             && defined $r->{_attributes} ) {
           $xml .= "$d  " . hash2xml( $depth+2, $r, $key ) . "\n";
+        } elsif( ref( $request->{$key} ) =~ /^ARRAY/ ) {
+          $xml .= hash2xml( $depth, $request->{$key}, $key );
         } else {
           my $data = hash2xml( $depth+2, $request->{$key}, $key );
           $xml .= "$d  <$key>$data</$key>\n";
